File reference - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# File reference

A `betty.ancestry.FileReference` describes the relationship between an entity and a File.

## Fields

`id` (`str`)

  The file reference’s own entity ID.

`file` (File)

  The referenced file.

`referee` (`betty.ancestry.HasFileReferences`)

  The entity referencing the file.